@@ -23,7 +23,7 @@
 #include "config.h"
 #endif
 #include <cstdio>
-#include <signal.h>
+#include <csignal>
 #include <cstring>
 #include <cstdlib>
 #include <sys/types.h>
@@ -37,7 +37,7 @@
 #include <sys/resource.h>
 #include <sys/time.h>
 #include <sys/wait.h>
-#include <errno.h>
+#include <cerrno>
 #include <pthread.h>
 #include <thread>
 #include <unistd.h>
@@ -196,6 +196,7 @@ static void declareArguments()
   ::arg().set("log-timestamp", "Print timestamps in log lines") = "yes";
   ::arg().set("distributor-threads", "Default number of Distributor (backend) threads to start") = "3";
   ::arg().set("signing-threads", "Default number of signer threads to start") = "3";
+  ::arg().setSwitch("workaround-11804", "Workaround for issue 11804: send single RR per AXFR chunk") = "no";
   ::arg().set("receiver-threads", "Default number of receiver threads to start") = "1";
   ::arg().set("queue-limit", "Maximum number of milliseconds to queue a query") = "1500";
   ::arg().set("resolver", "Use this resolver for ALIAS and the internal stub resolver") = "no";
@@ -334,7 +335,7 @@ static void declareArguments()
 }
 
 static time_t s_start = time(nullptr);
-static uint64_t uptimeOfProcess(const std::string& str)
+static uint64_t uptimeOfProcess(const std::string& /* str */)
 {
   return time(nullptr) - s_start;
 }
@@ -351,12 +352,12 @@ static uint64_t getSysUserTimeMsec(const std::string& str)
     return (ru.ru_utime.tv_sec * 1000ULL + ru.ru_utime.tv_usec / 1000);
 }
 
-static uint64_t getTCPConnectionCount(const std::string& str)
+static uint64_t getTCPConnectionCount(const std::string& /* str */)
 {
   return s_tcpNameserver->numTCPConnections();
 }
 
-static uint64_t getQCount(const std::string& str)
+static uint64_t getQCount(const std::string& /* str */)
 try {
   int totcount = 0;
   for (const auto& d : s_distributors) {
@@ -375,27 +376,27 @@ catch (PDNSException& e) {
   return 0;
 }
 
-static uint64_t getLatency(const std::string& str)
+static uint64_t getLatency(const std::string& /* str */)
 {
   return round(avg_latency);
 }
 
-static uint64_t getReceiveLatency(const std::string& str)
+static uint64_t getReceiveLatency(const std::string& /* str */)
 {
   return round(receive_latency);
 }
 
-static uint64_t getCacheLatency(const std::string& str)
+static uint64_t getCacheLatency(const std::string& /* str */)
 {
   return round(cache_latency);
 }
 
-static uint64_t getBackendLatency(const std::string& str)
+static uint64_t getBackendLatency(const std::string& /* str */)
 {
   return round(backend_latency);
 }
 
-static uint64_t getSendLatency(const std::string& str)
+static uint64_t getSendLatency(const std::string& /* str */)
 {
   return round(send_latency);
 }
@@ -489,7 +490,7 @@ static void declareStats()
   S.declare(
     "xfr-queue", "Size of the queue of zones to be XFRd", [](const string&) { return Communicator.getSuckRequestsWaiting(); }, StatType::gauge);
   S.declareDNSNameQTypeRing("queries", "UDP Queries Received");
-  S.declareDNSNameQTypeRing("nxdomain-queries", "Queries for non-existent records within existent zones");
+  S.declareDNSNameQTypeRing("nxdomain-queries", "Queries for nonexistent records within existent zones");
   S.declareDNSNameQTypeRing("noerror-queries", "Queries for existing records, but for type we don't have");
   S.declareDNSNameQTypeRing("servfail-queries", "Queries that could not be answered due to backend errors");
   S.declareDNSNameQTypeRing("unauth-queries", "Queries for zones that we are not authoritative for");
@@ -925,7 +926,7 @@ static void daemonize()
 }
 
 static int cpid;
-static void takedown(int i)
+static void takedown(int /* i */)
 {
   if (cpid) {
     g_log << Logger::Error << "Guardian is killed, taking down children with us" << endl;
@@ -963,7 +964,7 @@ static FILE* g_fp;
 static std::mutex g_guardian_lock;
 
 // The next two methods are not in dynhandler.cc because they use a few items declared in this file.
-static string DLCycleHandler(const vector<string>& parts, pid_t ppid)
+static string DLCycleHandler(const vector<string>& /* parts */, pid_t /* ppid */)
 {
   kill(cpid, SIGKILL); // why?
   kill(cpid, SIGKILL); // why?
@@ -971,7 +972,7 @@ static string DLCycleHandler(const vector<string>& parts, pid_t ppid)
   return "ok";
 }
 
-static string DLRestHandler(const vector<string>& parts, pid_t ppid)
+static string DLRestHandler(const vector<string>& parts, pid_t /* ppid */)
 {
   string line;
 
@@ -1113,7 +1114,7 @@ static int guardian(int argc, char** argv)
           // execute some kind of ping here
           if (DLQuitPlease())
             takedown(1); // needs a parameter..
-          setStatus("Child running on pid " + itoa(pid));
+          setStatus("Child running on pid " + std::to_string(pid));
           sleep(1);
         }
       }
@@ -1130,7 +1131,7 @@ static int guardian(int argc, char** argv)
           g_log << Logger::Error << "Child requested a stop, exiting" << endl;
           exit(1);
         }
-        setStatus("Child died with code " + itoa(ret));
+        setStatus("Child died with code " + std::to_string(ret));
         g_log << Logger::Error << "Our pdns instance exited with code " << ret << ", respawning" << endl;
 
         sleep(1);
@@ -1138,7 +1139,7 @@ static int guardian(int argc, char** argv)
       }
       if (WIFSIGNALED(status)) {
         int sig = WTERMSIG(status);
-        setStatus("Child died because of signal " + itoa(sig));
+        setStatus("Child died because of signal " + std::to_string(sig));
         g_log << Logger::Error << "Our pdns instance (" << pid << ") exited after signal " << sig << endl;
 #ifdef WCOREDUMP
         if (WCOREDUMP(status))
