@@ -37,16 +37,17 @@ bool getNextEDNSOption(const char* data, size_t dataLen, uint16_t& optionCode, u
 
   optionLen = (static_cast<uint16_t>(p[pos]) * 256) + p[pos + 1];
   pos += EDNS_OPTION_LENGTH_SIZE;
+  (void) pos;
 
   return true;
 }
 
-/* extract a specific EDNS0 option from a pointer on the beginning rdLen of the OPT RR */
-int getEDNSOption(char* optRR, const size_t len, uint16_t wantedOption, char ** optionValue, size_t * optionValueSize)
+/* extract the position (relative to the optRR pointer!) and size of a specific EDNS0 option from a pointer on the beginning rdLen of the OPT RR */
+int getEDNSOption(const char* optRR, const size_t len, uint16_t wantedOption, size_t* optionValuePosition, size_t * optionValueSize)
 {
-  assert(optRR != NULL);
-  assert(optionValue != NULL);
-  assert(optionValueSize != NULL);
+  assert(optRR != nullptr);
+  assert(optionValuePosition != nullptr);
+  assert(optionValueSize != nullptr);
   size_t pos = 0;
   if (len < DNS_RDLENGTH_SIZE)
     return EINVAL;
@@ -76,7 +77,7 @@ int getEDNSOption(char* optRR, const size_t len, uint16_t wantedOption, char **
     }
 
     if (optionCode == wantedOption) {
-      *optionValue = optRR + pos - (EDNS_OPTION_CODE_SIZE + EDNS_OPTION_LENGTH_SIZE);
+      *optionValuePosition = pos - (EDNS_OPTION_CODE_SIZE + EDNS_OPTION_LENGTH_SIZE);
       *optionValueSize = optionLen + EDNS_OPTION_CODE_SIZE + EDNS_OPTION_LENGTH_SIZE;
       return 0;
     }
@@ -93,7 +94,7 @@ int getEDNSOption(char* optRR, const size_t len, uint16_t wantedOption, char **
 /* extract all EDNS0 options from a pointer on the beginning rdLen of the OPT RR */
 int getEDNSOptions(const char* optRR, const size_t len, EDNSOptionViewMap& options)
 {
-  assert(optRR != NULL);
+  assert(optRR != nullptr);
   size_t pos = 0;
   if (len < DNS_RDLENGTH_SIZE)
     return EINVAL;
@@ -119,7 +120,7 @@ int getEDNSOptions(const char* optRR, const size_t len, EDNSOptionViewMap& optio
     EDNSOptionViewValue value;
     value.content = optRR + pos;
     value.size = optionLen;
-    options[optionCode].values.push_back(std::move(value));
+    options[optionCode].values.push_back(value);
 
     /* skip this option */
     pos += optionLen;
